pub fn percent_encode_component(value: &str) -> StringExpand description
Percent-encodes everything but ASCII alphanumerics, for a value placed in one URL path
segment or query parameter. Same encoding as url_encode, as a String.
pub fn percent_encode_component(value: &str) -> StringPercent-encodes everything but ASCII alphanumerics, for a value placed in one URL path
segment or query parameter. Same encoding as url_encode, as a String.